AiiDA-FLEUR Calculations — AiiDA-FLEUR 1.1.0 documentation

# AiiDA-FLEUR Calculations

AiiDA-FLEUR plugin consists of three main parts:

1. FLEUR input generator (Fleur input generator plugin)

2. FLEUR code (FLEUR code plugin)

Fleur input generator represents inpgen code, FLEUR code represents fleur and fleur_MPI codes.

Other codes from the Fleur family (GFleur) or which are built on top of FLEUR (Spex) are not supported yet.

- Fleur input generator plugin
  - Description
  - Inputs
  - Outputs
  - Errors
  - Additional advanced features
    - Retrieving more files
    - Retrieving less files
- FLEUR code plugin
  - Description
  - Inputs
  - Outputs
  - Errors
  - Additional advanced features
    - Adding command-line options
    - Retrieving more files
    - Retrieving less files
    - Copy more files remotely
    - Copy less files remotely